@@ -12,25 +12,23 @@ class CommandHandler:
         self.prefix = options.prefix
         self.loop = loop
 
-    def registerCommand(self, command, coro) -> None:
+    def registerCommand(self, command, coro, loop) -> None:
         
         if not asyncio.iscoroutinefunction(coro):
             raise TypeError("The event registered must be a coroutine")
 
-        setattr(self, command, coro)
+        setattr(self, command, (coro, loop))
 
-    def _schedule_event(self, coro, arg) -> None:
-
-        # I would like to find a replacement for the following, as it can be a bit slow to execute but it will do for now
-        self.loop.create_task(coro(arg))
+    def _schedule_event(self, loop, coro, arg) -> None:
+        asyncio.run_coroutine_threadsafe(coro(arg), loop)
 
     def run_command(self, message : RustChatMessage) -> None:
 
         command = message.message.split(" ")[0][len(self.prefix):]
 
         if hasattr(self, command):
-            coro = getattr(self, command)
+            coro, loop = getattr(self, command)
 
             time = CommandTime(datetime.utcfromtimestamp(message.time), message.time)
 
-            self._schedule_event(coro, Command(message.name, message.steamId, time, command, message.message.split(" ")[1:]))
+            self._schedule_event(loop, coro, Command(message.name, message.steamId, time, command, message.message.split(" ")[1:]))
